[OE-core] [PATCH 1/1] devtool: point runqemu to correct native bindir

2017-04-04 Thread brian avery
devtool/runqemu.py was relying on STAGING_BINDIR_NATIVE to find the host
tools it needed like qemu-system-.  In the post RSS world, this no
longer exists. This patch points it to
{STAGING_DIR}/{BUILD_ARCH}/{bindir_native}.

[YOCTO #11223]

Signed-off-by: brian avery 
---
 scripts/lib/devtool/runqemu.py | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

diff --git a/scripts/lib/devtool/runqemu.py b/scripts/lib/devtool/runqemu.py
index 641664e..e26cf28 100644
--- a/scripts/lib/devtool/runqemu.py
+++ b/scripts/lib/devtool/runqemu.py
@@ -32,7 +32,9 @@ def runqemu(args, config, basepath, workspace):
 tinfoil = setup_tinfoil(config_only=True, basepath=basepath)
 try:
 machine = tinfoil.config_data.getVar('MACHINE')
-bindir_native = tinfoil.config_data.getVar('STAGING_BINDIR_NATIVE')
+bindir_native = os.path.join(tinfoil.config_data.getVar('STAGING_DIR'),
+ tinfoil.config_data.getVar('BUILD_ARCH'),
+ 
tinfoil.config_data.getVar('bindir_native').lstrip(os.path.sep))
 finally:
 tinfoil.shutdown()
 
-- 
1.9.1

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 0/1] esdk: Fixes for runqemu and sysroot

2017-04-04 Thread brian avery
The removal of STAGING_BINDIR_NATIVE broke runqemu in the esdk. This patch 
points the
"devtool runqemu" into the correct native bindir where the necessary tools are
located.

This fixes Bug 11223.

-brian

The following changes since commit eff56e4f0d59b1d965a68e4f009b7f07717b7edd:

  bitbake: bitbake-user-manual: Fixed special character in -D output 
(2017-04-03 22:32:02 +0100)

are available in the git repository at:

  git://git.yoctoproject.org/poky-contrib bavery/esdk_sadqemu/bug11223
  
http://git.yoctoproject.org/cgit.cgi/poky-contrib/log/?h=bavery/esdk_sadqemu/bug11223

brian avery (1):
  devtool: point runqemu to correct native bindir

 scripts/lib/devtool/runqemu.py | 4 +++-
 1 file changed, 3 insertions(+), 1 deletion(-)

--
1.9.1
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] time to get rid of FILESDIR?

2017-04-04 Thread Robert P. J. Day

  the only references i see to the deprecated FILESDIR are historical,
none actually being used. what about just tossing it?

rday

-- 


Robert P. J. Day Ottawa, Ontario, CANADA
http://crashcourse.ca

Twitter:   http://twitter.com/rpjday
LinkedIn:   http://ca.linkedin.com/in/rpjday

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] ✗ patchtest: failure for sanity: explain where TMPDIR is if we're telling the user to delete it (rev2)

2017-04-04 Thread Paul Eggleton
On Wednesday, 5 April 2017 5:02:05 AM NZST Patchwork wrote:
> * Issue Patch line too long (current length 214)
> [test_max_line_length] Suggested fixShorten the corresponding patch
> line (max length supported 180) Patch   
> meta/classes/sanity.bbclass
>   Line +status.addresult("The layout of TMPDIR
> changed for Recipe Specific  ...

I'm not sure we need to be checking for this. If our code strictly adhered to 
a maximum line length already then maybe, but the vast majority of it doesn't 
at the moment.

Cheers,
Paul


-- 

Paul Eggleton
Intel Open Source Technology Centre
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 1/2] scripts: change way we find native tools (pseudo)

2017-04-04 Thread Seebs
On Tue,  4 Apr 2017 15:22:10 -0700
brian avery  wrote:

> oe-find-native-sysroot: Recipe Specific Sysroots have eliminated the
> large STAGING_DIR_NATIVE. Now, we will rely on the meta-ide-support
> sysroot that is what was populating the large STAGING_DIR_NATIVE in
> previous versions anyway. We now look for RECIPE_SYSROOT_NATIVE.

So far as I can tell, pseudo internals won't be affected, and this
sounds reasonable to me.

-s
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 2/2] meta-ide-support: exclude this recipe from rm_work

2017-04-04 Thread brian avery
The results of meta-ide-support are used by utilities like runqemu and
runqemu-extract-sdk.  Since the usr/bin that meta-ide-support creates is
subsequently removed bu rm_work, we exclude this recipe from the rm_work
list.

[YOCTO #9]

Signed-off-by: brian avery 
---
 meta/recipes-core/meta/meta-ide-support.bb | 1 +
 1 file changed, 1 insertion(+)

diff --git a/meta/recipes-core/meta/meta-ide-support.bb 
b/meta/recipes-core/meta/meta-ide-support.bb
index 1c4aded..0692ec8 100644
--- a/meta/recipes-core/meta/meta-ide-support.bb
+++ b/meta/recipes-core/meta/meta-ide-support.bb
@@ -4,6 +4,7 @@ LICENSE = "MIT"
 
 DEPENDS = "virtual/libc gdb-cross-${TARGET_ARCH} qemu-native 
qemu-helper-native unfs3-native"
 PR = "r3"
+RM_WORK_EXCLUDE += "${PN}"
 
 inherit meta toolchain-scripts nopackages
 
-- 
1.9.1

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 1/2] scripts: change way we find native tools (pseudo)

2017-04-04 Thread brian avery
oe-find-native-sysroot: Recipe Specific Sysroots have eliminated the
large STAGING_DIR_NATIVE. Now, we will rely on the meta-ide-support
sysroot that is what was populating the large STAGING_DIR_NATIVE in
previous versions anyway. We now look for RECIPE_SYSROOT_NATIVE.

[YOCTO #9]

Signed-off-by: brian avery 
---
 scripts/oe-find-native-sysroot | 8 
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/scripts/oe-find-native-sysroot b/scripts/oe-find-native-sysroot
index 13a5c46..3f4c29d 100755
--- a/scripts/oe-find-native-sysroot
+++ b/scripts/oe-find-native-sysroot
@@ -2,7 +2,7 @@
 #
 # Find a native sysroot to use - either from an in-tree OE build or
 # from a toolchain installation. It then ensures the variable
-# $OECORE_NATIVE_SYSROOT is set to the sysroot's base directory, and sets 
+# $OECORE_NATIVE_SYSROOT is set to the sysroot's base directory, and sets
 # $PSEUDO to the path of the pseudo binary.
 #
 # This script is intended to be run within other scripts by source'ing
@@ -54,10 +54,10 @@ if [ "x$OECORE_NATIVE_SYSROOT" = "x" ]; then
 exit 1
 fi
 touch conf/sanity.conf
-OECORE_NATIVE_SYSROOT=`bitbake -e | grep ^STAGING_DIR_NATIVE | cut 
-d '"' -f2`
+OECORE_NATIVE_SYSROOT=`bitbake -e meta-ide-support | grep 
^RECIPE_SYSROOT_NATIVE | cut -d '"' -f2`
 rm -f conf/sanity.conf
 else
-OECORE_NATIVE_SYSROOT=`bitbake -e | grep ^STAGING_DIR_NATIVE | cut 
-d '"' -f2`
+OECORE_NATIVE_SYSROOT=`bitbake -e meta-ide-support | grep 
^RECIPE_SYSROOT_NATIVE | cut -d '"' -f2`
 fi
 else
 echo "Error: Unable to locate bitbake command."
@@ -72,7 +72,7 @@ fi
 if [ "x$OECORE_NATIVE_SYSROOT" = "x" ]; then
 # This indicates that there was an error running bitbake -e that
 # the user needs to be informed of
-echo "There was an error running bitbake to determine STAGING_DIR_NATIVE"
+echo "There was an error running bitbake to determine 
RECIPE_SYSROOT_NATIVE"
 echo "Here is the output from bitbake -e"
 bitbake -e
 exit 1
-- 
1.9.1

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 0/2] runqemu-extract-sdk: Fixes for RSS

2017-04-04 Thread brian avery

RSS removed the "giant native sysroot" so now we need a modify how tools like 
runqemu and
runqemu-extract-sdk find the native tools they need to run.  This patch uses 
the result of
meta-ide-support which has pseudo as well as tools like unfsd in it's usr/bin 
to run.
Since the meta-ide-support make a usr/bin dir in tmp/work and rm_work 
sibsequently removes it,
we exlude meta-ide-support from the rm_work set.

-brian

The following changes since commit eff56e4f0d59b1d965a68e4f009b7f07717b7edd:

  bitbake: bitbake-user-manual: Fixed special character in -D output 
(2017-04-03 22:32:02 +0100)

are available in the git repository at:

  git://git.yoctoproject.org/poky-contrib bavery/sadpseudo/bug9
  
http://git.yoctoproject.org/cgit.cgi/poky-contrib/log/?h=bavery/sadpseudo/bug9

brian avery (2):
  scripts: change way we find native tools (pseudo)
  meta-ide-support: exclude this recipe from rm_work

 meta/recipes-core/meta/meta-ide-support.bb | 1 +
 scripts/oe-find-native-sysroot | 8 
 2 files changed, 5 insertions(+), 4 deletions(-)

--
1.9.1
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH] create-pull-request: add "-t in-reply-to" option

2017-04-04 Thread Jose Lamego
The create-patch-request script creates patches as replies to a cover
letter, in the form of an email thread. If further revisions are sent to
the mailing list without referencing to the first revision, these new
revisions are not identified at the mailing list as part of the original
thread, but as a new thread instead.

This change adds the "[-t in_reply_to]" option, where "in_reply_to" is
the original cover letter's Message-Id, so this reference is added
to the new cover letter to ensure the thread continuity.

[YOCTO #11294]

Signed-off-by: Jose Lamego 
---
 scripts/create-pull-request | 14 +++---
 1 file changed, 11 insertions(+), 3 deletions(-)

diff --git a/scripts/create-pull-request b/scripts/create-pull-request
index e82858b..46d6538 100755
--- a/scripts/create-pull-request
+++ b/scripts/create-pull-request
@@ -34,7 +34,7 @@ RFC=0
 usage() {
 CMD=$(basename $0)
 cat <"
 EOM
 }
 
 REMOTE="$CPR_CONTRIB_REMOTE"
 # Parse and validate arguments
-while getopts "b:acd:hi:m:o:p:r:s:u:l:" OPT; do
+while getopts "b:acd:hi:m:o:p:r:s:u:l:t:" OPT; do
case $OPT in
b)
BRANCH="$OPTARG"
@@ -108,6 +110,8 @@ while getopts "b:acd:hi:m:o:p:r:s:u:l:" OPT; do
a)
CPR_CONTRIB_AUTO_PUSH="1"
;;
+t)
+IN_REPLY_TO="$OPTARG"
esac
 done
 
@@ -205,7 +209,11 @@ if [ -n "$RELDIR" ]; then
 fi
 
 # Generate the patches and cover letter
-git format-patch $extraopts -M40 --subject-prefix="$PREFIX" -n -o $ODIR 
--thread=shallow --cover-letter $RELATIVE_TO..$COMMIT_ID > /dev/null
+if [ -z "$IN_REPLY_TO" ]; then
+git format-patch $extraopts -M40 --subject-prefix="$PREFIX" -n -o $ODIR 
--thread=shallow --in-reply-to="$IN_REPLY_TO" --cover-letter 
$RELATIVE_TO..$COMMIT_ID > /dev/null
+else
+git format-patch $extraopts -M40 --subject-prefix="$PREFIX" -n -o $ODIR 
--thread=shallow --cover-letter $RELATIVE_TO..$COMMIT_ID > /dev/null
+fi
 
 if [ -z "$(ls -A $ODIR 2> /dev/null)" ]; then
 echo "ERROR: $ODIR is empty, no cover letter and patches was generated!"
-- 
2.10.2

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 1/2] selftest/commands: extend variable regex to include A_B variable notation

2017-04-04 Thread leonardo . sandoval . gonzalez
From: Leonardo Sandoval 

This change allows quering for variables with the format A_B, i.e.
PREFERRED_PROVIDER_virtual/kernel instead of just A.

Signed-off-by: Leonardo Sandoval 
---
 meta/lib/oeqa/utils/commands.py | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/meta/lib/oeqa/utils/commands.py b/meta/lib/oeqa/utils/commands.py
index 2951dfb..57286fc 100644
--- a/meta/lib/oeqa/utils/commands.py
+++ b/meta/lib/oeqa/utils/commands.py
@@ -165,7 +165,7 @@ def get_bb_vars(variables=None, target=None, 
postconfig=None):
 
 if variables is not None:
 variables = variables.copy()
-var_re = re.compile(r'^(export )?(?P\w+)="(?P.*)"$')
+var_re = re.compile(r'^(export )?(?P\w+(_.*)?)="(?P.*)"$')
 unset_re = re.compile(r'^unset (?P\w+)$')
 lastline = None
 values = {}
-- 
2.10.2

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH] sanity: explain where TMPDIR is if we're telling the user to delete it

2017-04-04 Thread Burton, Ross
On 4 April 2017 at 16:13, Christopher Larson  wrote:

> This looks good, though I wonder if we should explicitly state that it
> should be removed. I could see someone wondering how they “clean” their
> tmpdir :)
>

Good point, v2 sent.

Ross
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH V2] sanity: explain where TMPDIR is if we're telling the user to delete it

2017-04-04 Thread Ross Burton
Signed-off-by: Ross Burton 
---
 meta/classes/sanity.bbclass | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/meta/classes/sanity.bbclass b/meta/classes/sanity.bbclass
index 94c78b5..e8064ac 100644
--- a/meta/classes/sanity.bbclass
+++ b/meta/classes/sanity.bbclass
@@ -589,7 +589,7 @@ def sanity_handle_abichanges(status, d):
 with open(abifile, "w") as f:
 f.write(current_abi)
 elif int(abi) <= 11 and current_abi == "12":
-status.addresult("The layout of TMPDIR changed for Recipe Specific 
Sysroots.\nConversion doesn't make sense and this change will rebuild 
everything so please start with a clean TMPDIR.\n")
+status.addresult("The layout of TMPDIR changed for Recipe Specific 
Sysroots.\nConversion doesn't make sense and this change will rebuild 
everything so please delete TMPDIR (%s).\n" % d.getVar("TMPDIR"))
 elif (abi != current_abi):
 # Code to convert from one ABI to another could go here if 
possible.
 status.addresult("Error, TMPDIR has changed its layout version 
number (%s to %s) and you need to either rebuild, revert or adjust it at your 
own risk.\n" % (abi, current_abi))
-- 
2.8.1

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH] sanity: explain where TMPDIR is if we're telling the user to delete it

2017-04-04 Thread Christopher Larson
On Tue, Apr 4, 2017 at 7:22 AM, Ross Burton  wrote:

> Signed-off-by: Ross Burton 
> ---
>  meta/classes/sanity.bbclass | 2 +-
>  1 file changed, 1 insertion(+), 1 deletion(-)
>
> diff --git a/meta/classes/sanity.bbclass b/meta/classes/sanity.bbclass
> index 94c78b5..ade8cb6 100644
> --- a/meta/classes/sanity.bbclass
> +++ b/meta/classes/sanity.bbclass
> @@ -589,7 +589,7 @@ def sanity_handle_abichanges(status, d):
>  with open(abifile, "w") as f:
>  f.write(current_abi)
>  elif int(abi) <= 11 and current_abi == "12":
> -status.addresult("The layout of TMPDIR changed for Recipe
> Specific Sysroots.\nConversion doesn't make sense and this change will
> rebuild everything so please start with a clean TMPDIR.\n")
> +status.addresult("The layout of TMPDIR changed for Recipe
> Specific Sysroots.\nConversion doesn't make sense and this change will
> rebuild everything so please start with a clean TMPDIR (%s).\n" %
> d.getVar("TMPDIR"))
>

This looks good, though I wonder if we should explicitly state that it
should be removed. I could see someone wondering how they “clean” their
tmpdir :)
-- 
Christopher Larson
kergoth at gmail dot com
Founder - BitBake, OpenEmbedded, OpenZaurus
Senior Software Engineer, Mentor Graphics
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH] glibc: fix nativesdk ldd RTLDLIST

2017-04-04 Thread liu . ming50
From: Ming Liu 

Override RTLDLIST for nativesdk, or else ldd would fail to run on
SDK targets.

Signed-off-by: Ming Liu 
---
 meta/recipes-core/glibc/glibc-ld.inc | 1 +
 1 file changed, 1 insertion(+)

diff --git a/meta/recipes-core/glibc/glibc-ld.inc 
b/meta/recipes-core/glibc/glibc-ld.inc
index b89b70a..c1d635d 100644
--- a/meta/recipes-core/glibc/glibc-ld.inc
+++ b/meta/recipes-core/glibc/glibc-ld.inc
@@ -44,4 +44,5 @@ def glibc_dl_info(d):
 
 EGLIBC_KNOWN_INTERPRETER_NAMES = "${@glibc_dl_info(d)['ldconfig']}"
 RTLDLIST = "${@glibc_dl_info(d)['lddrewrite']}"
+RTLDLIST_class-nativesdk = "${base_libdir}/${@bb.utils.contains('SDK_ARCH', 
'x86_64', 'ld-linux-x86-64.so.2', 'ld-linux.so.2', d)}"
 glibc_dl_info[vardepsexclude] = "OVERRIDES"
-- 
2.7.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] ✗ patchtest: failure for sanity: explain where TMPDIR is if we're telling the user to delete it

2017-04-04 Thread Patchwork
== Series Details ==

Series: sanity: explain where TMPDIR is if we're telling the user to delete it
Revision: 1
URL   : https://patchwork.openembedded.org/series/6146/
State : failure

== Summary ==


Thank you for submitting this patch series to OpenEmbedded Core. This is
an automated response. Several tests have been executed on the proposed
series by patchtest resulting in the following failures:



* Issue Patch line too long (current length 226) 
[test_max_line_length] 
  Suggested fixShorten the corresponding patch line (max length supported 
180)
  Patchmeta/classes/sanity.bbclass
  Line +status.addresult("The layout of TMPDIR changed 
for Recipe Specific  ...



If you believe any of these test results are incorrect, please reply to the
mailing list (openembedded-core@lists.openembedded.org) raising your concerns.
Otherwise we would appreciate you correcting the issues and submitting a new
version of the patchset if applicable. Please ensure you add/increment the
version number when sending the new version (i.e. [PATCH] -> [PATCH v2] ->
[PATCH v3] -> ...).

---
Test framework: http://git.yoctoproject.org/cgit/cgit.cgi/patchtest
Test suite: http://git.yoctoproject.org/cgit/cgit.cgi/patchtest-oe

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH] runtime/dnf : Add ID to the dnf test cases

2017-04-04 Thread jose . perez . carranza
From: Jose Perez Carranza 

Add the corresponding Testopia ID to the test cases for dnf

Signed-off-by: Jose Perez Carranza 
---
 meta/lib/oeqa/runtime/cases/dnf.py | 12 
 1 file changed, 12 insertions(+)

diff --git a/meta/lib/oeqa/runtime/cases/dnf.py 
b/meta/lib/oeqa/runtime/cases/dnf.py
index eb3af07f0f..2f87296b4e 100644
--- a/meta/lib/oeqa/runtime/cases/dnf.py
+++ b/meta/lib/oeqa/runtime/cases/dnf.py
@@ -26,22 +26,27 @@ class DnfBasicTest(DnfTest):
   'RPM is not the primary package manager')
 @OEHasPackage(['dnf'])
 @OETestDepends(['ssh.SSHTest.test_ssh'])
+@OETestID(1735)
 def test_dnf_help(self):
 self.dnf('--help')
 
 @OETestDepends(['dnf.DnfBasicTest.test_dnf_help'])
+@OETestID(1739)
 def test_dnf_version(self):
 self.dnf('--version')
 
 @OETestDepends(['dnf.DnfBasicTest.test_dnf_help'])
+@OETestID(1737)
 def test_dnf_info(self):
 self.dnf('info dnf')
 
 @OETestDepends(['dnf.DnfBasicTest.test_dnf_help'])
+@OETestID(1738)
 def test_dnf_search(self):
 self.dnf('search dnf')
 
 @OETestDepends(['dnf.DnfBasicTest.test_dnf_help'])
+@OETestID(1736)
 def test_dnf_history(self):
 self.dnf('history')
 
@@ -65,6 +70,7 @@ class DnfRepoTest(DnfTest):
 self.dnf(" ".join(cmdlinerepoopts) + " --nogpgcheck " + command)
 
 @OETestDepends(['dnf.DnfBasicTest.test_dnf_help'])
+@OETestID(1744)
 def test_dnf_makecache(self):
 self.dnf_with_repo('makecache')
 
@@ -75,19 +81,23 @@ class DnfRepoTest(DnfTest):
 #self.dnf_with_repo('repolist')
 
 @OETestDepends(['dnf.DnfRepoTest.test_dnf_makecache'])
+@OETestID(1746)
 def test_dnf_repoinfo(self):
 self.dnf_with_repo('repoinfo')
 
 @OETestDepends(['dnf.DnfRepoTest.test_dnf_makecache'])
+@OETestID(1740)
 def test_dnf_install(self):
 self.dnf_with_repo('install -y run-postinsts-dev')
 
 @OETestDepends(['dnf.DnfRepoTest.test_dnf_install'])
+@OETestID(1741)
 def test_dnf_install_dependency(self):
 self.dnf_with_repo('remove -y run-postinsts')
 self.dnf_with_repo('install -y run-postinsts-dev')
 
 @OETestDepends(['dnf.DnfRepoTest.test_dnf_install_dependency'])
+@OETestID(1742)
 def test_dnf_install_from_disk(self):
 self.dnf_with_repo('remove -y run-postinsts-dev')
 self.dnf_with_repo('install -y --downloadonly run-postinsts-dev')
@@ -96,6 +106,7 @@ class DnfRepoTest(DnfTest):
 self.dnf_with_repo('install -y %s' % output)
 
 @OETestDepends(['dnf.DnfRepoTest.test_dnf_install_from_disk'])
+@OETestID(1743)
 def test_dnf_install_from_http(self):
 output = subprocess.check_output('%s %s -name run-postinsts-dev*' % 
(bb.utils.which(os.getenv('PATH'), "find"),

os.path.join(self.tc.td['WORKDIR'], 'oe-testimage-repo')), 
shell=True).decode("utf-8")
@@ -105,6 +116,7 @@ class DnfRepoTest(DnfTest):
 self.dnf_with_repo('install -y %s' % url)
 
 @OETestDepends(['dnf.DnfRepoTest.test_dnf_install'])
+@OETestID(1745)
 def test_dnf_reinstall(self):
 self.dnf_with_repo('reinstall -y run-postinsts-dev')
 
-- 
2.11.0

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH] gpgme: fix configure if 'import distutils' causes output on stderr

2017-04-04 Thread Ross Burton
There are a number of reasons that importing a module could cause output on
stderr that isn't a fatal error (compatibilty problems with inputrc, or encoding
warnings) so backport a patch from autoconf-archive to only check the exit code
instead of asserting that stderr is empty.

[ YOCTO #11231 ]

Signed-off-by: Ross Burton 
---
 meta/recipes-support/gpgme/gpgme/python-import.patch | 19 +++
 meta/recipes-support/gpgme/gpgme_1.8.0.bb|  2 +-
 2 files changed, 20 insertions(+), 1 deletion(-)
 create mode 100644 meta/recipes-support/gpgme/gpgme/python-import.patch

diff --git a/meta/recipes-support/gpgme/gpgme/python-import.patch 
b/meta/recipes-support/gpgme/gpgme/python-import.patch
new file mode 100644
index 000..61b77a1
--- /dev/null
+++ b/meta/recipes-support/gpgme/gpgme/python-import.patch
@@ -0,0 +1,19 @@
+Don't check for output on stderr to know if an import worked, host inputrc and
+sysroot readline can cause warnings on stderr.
+
+Upstream-Status: Backport (from autoconf-archive 883a2abd)
+Signed-off-by: Ross Burton 
+
+diff --git a/m4/ax_python_devel.m4 b/m4/ax_python_devel.m4
+index b990d5b..318b089 100644
+--- a/m4/ax_python_devel.m4
 b/m4/ax_python_devel.m4
+@@ -137,7 +137,7 @@ variable to configure. See ``configure --help'' for 
reference.
+   #
+   AC_MSG_CHECKING([for the distutils Python package])
+   ac_distutils_result=`$PYTHON -c "import distutils" 2>&1`
+-  if test -z "$ac_distutils_result"; then
++  if test $? -eq 0; then
+   AC_MSG_RESULT([yes])
+   else
+   AC_MSG_RESULT([no])
diff --git a/meta/recipes-support/gpgme/gpgme_1.8.0.bb 
b/meta/recipes-support/gpgme/gpgme_1.8.0.bb
index 2756ef8..eddf3a0 100644
--- a/meta/recipes-support/gpgme/gpgme_1.8.0.bb
+++ b/meta/recipes-support/gpgme/gpgme_1.8.0.bb
@@ -15,6 +15,7 @@ SRC_URI = "${GNUPG_MIRROR}/gpgme/${BP}.tar.bz2 \
file://python-lang-config.patch \
file://0001-Correctly-install-python-modules.patch \
file://0001-Avoid-host-contamination-from-gpg-config.patch \
+   file://python-import.patch \
   "
 
 SRC_URI[md5sum] = "722a4153904b9b5dc15485a22d29263b"
@@ -70,4 +71,3 @@ do_configure_prepend () {
rm -f ${S}/m4/gpg-error.m4
rm -f ${S}/m4/libassuan.m4
 }
-
-- 
2.8.1

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH] sanity: explain where TMPDIR is if we're telling the user to delete it

2017-04-04 Thread Ross Burton
Signed-off-by: Ross Burton 
---
 meta/classes/sanity.bbclass | 2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

diff --git a/meta/classes/sanity.bbclass b/meta/classes/sanity.bbclass
index 94c78b5..ade8cb6 100644
--- a/meta/classes/sanity.bbclass
+++ b/meta/classes/sanity.bbclass
@@ -589,7 +589,7 @@ def sanity_handle_abichanges(status, d):
 with open(abifile, "w") as f:
 f.write(current_abi)
 elif int(abi) <= 11 and current_abi == "12":
-status.addresult("The layout of TMPDIR changed for Recipe Specific 
Sysroots.\nConversion doesn't make sense and this change will rebuild 
everything so please start with a clean TMPDIR.\n")
+status.addresult("The layout of TMPDIR changed for Recipe Specific 
Sysroots.\nConversion doesn't make sense and this change will rebuild 
everything so please start with a clean TMPDIR (%s).\n" % d.getVar("TMPDIR"))
 elif (abi != current_abi):
 # Code to convert from one ABI to another could go here if 
possible.
 status.addresult("Error, TMPDIR has changed its layout version 
number (%s to %s) and you need to either rebuild, revert or adjust it at your 
own risk.\n" % (abi, current_abi))
-- 
2.8.1

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH] selftest/devtool: skip test in case of poky-tiny distro

2017-04-04 Thread Leonardo Sandoval
On Tue, 2017-04-04 at 11:22 +0100, Burton, Ross wrote:
> 
> On 4 April 2017 at 05:20, 
> wrote:
> The recipe being tested (devtoo-test-patch-gz) by devtool has
> dependencies (at
> least libxres and virtual/libx11) that cannot be built with
> poky-tiny distro so
> skip the test for this particular policy.
> 
> 
> I think that whilst this is probably a good fix for now as we're
> trying to stabilise, changing the test so that it can be built with
> poky-tiny would be sensible.

Agree. We need to think of a 'simpler recipe' used by devtool test case
that can be used together with non-poky distros.
> 
> 
> Ross


-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH v2 0/8] Build perf test enhancements

2017-04-04 Thread Markus Lehtonen
Only change since v1 is one new patch for oe-build-perf-report-email.py.


The following changes since commit 3b7111b30dbd9a4cdd141b594164da18c15ae970:

  automake: Adjust shebang lines to remove interpreter path hardcode 
(2017-04-01 08:22:04 +0100)

are available in the git repository at:

  git://git.openembedded.org/openembedded-core-contrib marquiz/buildperf/scripts
  
http://git.openembedded.org/openembedded-core-contrib/log/?h=marquiz/buildperf/scripts


Markus Lehtonen (8):
  scripts/oe-build-perf-report: better guessing of args
  scripts/oe-build-perf-report: fix 'charts ready' console message
  scripts/oe-build-perf-report: fix typo
  build-perf-test-wrapper.sh: make it possible to specify Git branch
name
  build-perf-test-wrapper.sh: correctly check test script exit status
  build-perf-test-wrapper.sh: support pushing to remote Git
  build-perf-test-wrapper.sh: support sending email reports
  oe-build-perf-report-email.py: fix one file path

 scripts/contrib/build-perf-test-wrapper.sh | 70 +-
 scripts/contrib/oe-build-perf-report-email.py  |  2 +-
 scripts/lib/build_perf/html/measurement_chart.html |  6 +-
 scripts/lib/build_perf/html/report.html|  5 +-
 scripts/oe-build-perf-report   |  4 +-
 5 files changed, 63 insertions(+), 24 deletions(-)

-- 
2.10.2

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] tainting other recipe's specific task

2017-04-04 Thread André Draszik
Hi,

Is it possible to invalidate one recipe's hash for a specific task from
another recipe?

More specifically, I have an initramfs image recipe and a main image recipe
where do_rootfs of the main image [depends] on do_deploy of initramfs.

If do_rootfs of the main image needs to be re-run, I need to make sure that
do_rootfs of the initramfs image is re-run (and of course do_deploy) before.
Basically I want to add a timestamp to both images, and the timestamp should
be the same.

Using my current dependencies, do_rootfs of the main image is re-run if the
initramfs is re-deployed:

--- snip main_image.bb: ---
do_rootfs[depends] += "initramfs:do_deploy"
--- snap ---

but I need this both ways. Just adding the equivalent to the initramfs
recipe results in bitbake complaining about a recursive dependency loop.


Can this be achieved? Even some pointers would be helpful...


Or some other approach where I can add the same timestamp to both images if
either of the images needed to be rebuilt due to some change?


Cheers,
Andre'

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] ✗ patchtest: failure for oe-selftest: test wic sparse_copy API

2017-04-04 Thread Patchwork
== Series Details ==

Series: oe-selftest: test wic sparse_copy API
Revision: 1
URL   : https://patchwork.openembedded.org/series/6144/
State : failure

== Summary ==


Thank you for submitting this patch series to OpenEmbedded Core. This is
an automated response. Several tests have been executed on the proposed
series by patchtest resulting in the following failures:



* Issue Series does not apply on top of target branch 
[test_series_merge_on_head] 
  Suggested fixRebase your series on top of targeted branch
  Targeted branch  master (currently at 3b7111b30d)



If you believe any of these test results are incorrect, please reply to the
mailing list (openembedded-core@lists.openembedded.org) raising your concerns.
Otherwise we would appreciate you correcting the issues and submitting a new
version of the patchset if applicable. Please ensure you add/increment the
version number when sending the new version (i.e. [PATCH] -> [PATCH v2] ->
[PATCH v3] -> ...).

---
Test framework: http://git.yoctoproject.org/cgit/cgit.cgi/patchtest
Test suite: http://git.yoctoproject.org/cgit/cgit.cgi/patchtest-oe

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH] oe-selftest: test wic sparse_copy API

2017-04-04 Thread Ed Bartosh
Added new parameter 'api' to sparse_copy function to specify
underlying filemap API to use. By default sparse_copy will
try both available APIs.

Added test case for sparse_copy to wic test suite.

Signed-off-by: Ed Bartosh 
---
 meta/lib/oeqa/selftest/wic.py | 26 ++
 scripts/lib/wic/filemap.py|  6 --
 2 files changed, 30 insertions(+), 2 deletions(-)

diff --git a/meta/lib/oeqa/selftest/wic.py b/meta/lib/oeqa/selftest/wic.py
index df5e060..7e26dde 100644
--- a/meta/lib/oeqa/selftest/wic.py
+++ b/meta/lib/oeqa/selftest/wic.py
@@ -24,6 +24,7 @@
 """Test cases for wic."""
 
 import os
+import sys
 import unittest
 
 from glob import glob
@@ -758,3 +759,28 @@ part /etc --source rootfs --ondisk mmcblk0 --fstype=ext4 
--exclude-path bin/ --r
 self.assertEqual(0, runCmd(cmd).status)
 self.remove_config(config)
 self.assertEqual(1, len(glob(self.resultdir + 
"sdimage-bootpart-*direct")))
+
+def test_sparse_copy(self):
+"""Test sparse_copy with FIEMAP and SEEK_HOLE filemap APIs"""
+libpath = os.path.join(get_bb_var('COREBASE'), 'scripts', 'lib', 'wic')
+sys.path.insert(0, libpath)
+from  filemap import FilemapFiemap, FilemapSeek, sparse_copy
+with NamedTemporaryFile("w", suffix=".wic-sparse") as sparse:
+src_name = sparse.name
+src_size = 1024 * 10
+sparse.truncate(src_size)
+# write one byte to the file
+with open(src_name, 'r+b') as sfile:
+sfile.seek(1024 * 4)
+sfile.write(b'\x00')
+dest = sparse.name + '.out'
+# copy src file to dest using different filemap APIs
+for api in (FilemapFiemap, FilemapSeek, None):
+if os.path.exists(dest):
+os.unlink(dest)
+sparse_copy(sparse.name, dest, api=api)
+dest_stat = os.stat(dest)
+self.assertEqual(dest_stat.st_size, src_size)
+# 8 blocks is 4K (physical sector size)
+self.assertEqual(dest_stat.st_blocks, 8)
+os.unlink(dest)
diff --git a/scripts/lib/wic/filemap.py b/scripts/lib/wic/filemap.py
index 080668e..1f1aacc 100644
--- a/scripts/lib/wic/filemap.py
+++ b/scripts/lib/wic/filemap.py
@@ -530,9 +530,11 @@ def filemap(image, log=None):
 except ErrorNotSupp:
 return FilemapSeek(image, log)
 
-def sparse_copy(src_fname, dst_fname, offset=0, skip=0):
+def sparse_copy(src_fname, dst_fname, offset=0, skip=0, api=None):
 """Efficiently copy sparse file to or into another file."""
-fmap = filemap(src_fname)
+if not api:
+api = filemap
+fmap = api(src_fname)
 try:
 dst_file = open(dst_fname, 'r+b')
 except IOError:
-- 
2.1.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH] ethtool: Switch to download mirror

2017-04-04 Thread Burton, Ross
On 3 April 2017 at 16:39, Leonardo Sandoval <
leonardo.sandoval.gonza...@linux.intel.com> wrote:

> so why the sums are not changed in the recipe if these change at the
> upstream repo?
>

Because the patch changes the SRC_URI to point at our mirror, which
contains the old tarball.

Ross
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH v2 4/8] logrotate: replace fedorahosted.org SRC_URI with github.com source

2017-04-04 Thread Alexander Kanavin

On 04/04/2017 12:29 PM, yin.thong.cho...@intel.com wrote:

-SRC_URI = 
"https://fedorahosted.org/releases/l/o/logrotate/logrotate-${PV}.tar.gz \
+S = "${WORKDIR}/${PN}-r3-9-1"
+
+UPSTREAM_CHECK_URI = "https://github.com/${PN}/${PN}/releases;
+
+SRC_URI = "https://github.com/${PN}/${PN}/archive/r3-9-1.tar.gz \


Why are we taking a github snapshot tarball (which is not standard 
parctice in oe-core)? Put a comment here that when updating logrotate to 
latest upstream, SRC_URI should point to a proper release tarball from 
https://github.com/logrotate/logrotate/releases and we have to take the 
snapshot for now because there is no such tarball available for 3.9.1.


Generally, don't be afraid to put comments next to your changes, the 
more the better! And especially when you are doing something unusual 
that is not self-explanatory like above.


Otherwise, I am happy with the patchset!

Alex

--
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH] selftest/devtool: skip test in case of poky-tiny distro

2017-04-04 Thread Burton, Ross
On 4 April 2017 at 05:20, 
wrote:

> The recipe being tested (devtoo-test-patch-gz) by devtool has dependencies
> (at
> least libxres and virtual/libx11) that cannot be built with poky-tiny
> distro so
> skip the test for this particular policy.
>

I think that whilst this is probably a good fix for now as we're trying to
stabilise, changing the test so that it can be built with poky-tiny would
be sensible.

Ross
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH] x86-base.inc, qemuarm.conf: prefer 4.10 version of linux-yocto

2017-04-04 Thread Burton, Ross
On 4 April 2017 at 09:02, Martin Jansa  wrote:

> -PREFERRED_VERSION_linux-yocto ??= "4.8%"
> +PREFERRED_VERSION_linux-yocto ??= "4.10%"
>

The qemuppc and qemumips machines don't have a preferred version, so should
we be setting it in all the machine configurations, or can we remove it
from these recipes?

Ross
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH v2 6/8] liberation-fonts: replace fedorahosted.org SRC_URI with pagure.io source

2017-04-04 Thread yin . thong . choong
From: Choong YinThong 

fedorahosted.org was retired on March 1st, 2017. This is to
update the SRC_URI to point to pagure.io. pagure.io is a
replacement for fedorahosted.

[YOCTO #11226]

Signed-off-by: Choong YinThong 
---
 meta/recipes-graphics/ttf-fonts/liberation-fonts_1.04.bb | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/meta/recipes-graphics/ttf-fonts/liberation-fonts_1.04.bb 
b/meta/recipes-graphics/ttf-fonts/liberation-fonts_1.04.bb
index bda82e7..74212e7 100644
--- a/meta/recipes-graphics/ttf-fonts/liberation-fonts_1.04.bb
+++ b/meta/recipes-graphics/ttf-fonts/liberation-fonts_1.04.bb
@@ -2,7 +2,7 @@ SUMMARY = "Liberation(tm) Fonts"
 DESCRIPTION = "The Liberation(tm) Fonts is a font family originally \
 created by Ascender(c) which aims at metric compatibility with \
 Arial, Times New Roman, Courier New."
-HOMEPAGE = "https://fedorahosted.org/liberation-fonts/;
+HOMEPAGE = "https://releases.pagure.org/liberation-fonts/;
 BUGTRACKER = "https://bugzilla.redhat.com/;
 
 RECIPE_NO_UPDATE_REASON = "2.x depends on fontforge package, which is not yet 
provided in oe-core"
@@ -17,7 +17,7 @@ inherit allarch fontcache
 
 FONT_PACKAGES = "${PN}"
 
-SRC_URI = 
"https://fedorahosted.org/releases/l/i/liberation-fonts/liberation-fonts-${PV}.tar.gz
 \
+SRC_URI = 
"https://releases.pagure.org/liberation-fonts/liberation-fonts-${PV}.tar.gz \
file://30-liberation-aliases.conf"
 
 SRC_URI[md5sum] = "4846797ef0fc70b0cbaede2514677c58"
-- 
2.7.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH v2 8/8] cronie: replace fedorahosted.org SRC_URI with github.com source

2017-04-04 Thread yin . thong . choong
From: Choong YinThong 

fedorahosted.org was retired on March 1st, 2017. This is to
update the SRC_URI to point to github.com. This github link
is distributions to fedoreproject.org and the contact
Mailing list: cronie-devel AT lists.fedorahosted DOT org

[YOCTO #11226]

Signed-off-by: Choong YinThong 
---
 meta/recipes-extended/cronie/cronie_1.5.1.bb | 6 --
 1 file changed, 4 insertions(+), 2 deletions(-)

diff --git a/meta/recipes-extended/cronie/cronie_1.5.1.bb 
b/meta/recipes-extended/cronie/cronie_1.5.1.bb
index ad616d5..cfb8c21 100644
--- a/meta/recipes-extended/cronie/cronie_1.5.1.bb
+++ b/meta/recipes-extended/cronie/cronie_1.5.1.bb
@@ -3,7 +3,7 @@ DESCRIPTION = "Cronie contains the standard UNIX daemon crond 
that runs \
 specified programs at scheduled times and related tools. It is based on the \
 original cron and has security and configuration enhancements like the \
 ability to use pam and SELinux."
-HOMEPAGE = "https://fedorahosted.org/cronie/;
+HOMEPAGE = "https://github.com/cronie-crond/cronie/;
 BUGTRACKER = "https://bugzilla.redhat.com;
 
 # Internet Systems Consortium License
@@ -14,7 +14,9 @@ LIC_FILES_CHKSUM = 
"file://COPYING;md5=dd2a592170760e1386c769e1043b3722 \
 
 SECTION = "utils"
 
-SRC_URI = "https://fedorahosted.org/releases/c/r/cronie/cronie-${PV}.tar.gz \
+UPSTREAM_CHECK_URI = "https://github.com/cronie-crond/${BPN}/releases/;
+
+SRC_URI = 
"https://github.com/cronie-crond/cronie/releases/download/cronie-${PV}/cronie-${PV}.tar.gz
 \
file://crond.init \
file://crontab \
file://crond.service \
-- 
2.7.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH v2 7/8] chkconfig: replace fedorahosted.org SRC_URI with github.com source

2017-04-04 Thread yin . thong . choong
From: Choong YinThong 

fedorahosted.org was retired on March 1st, 2017. This is to update
the SRC_URI to point to github.com.

[YOCTO #11226]

Signed-off-by: Choong YinThong 
---
 meta/recipes-extended/chkconfig/chkconfig_1.3.58.bb | 12 
 1 file changed, 8 insertions(+), 4 deletions(-)

diff --git a/meta/recipes-extended/chkconfig/chkconfig_1.3.58.bb 
b/meta/recipes-extended/chkconfig/chkconfig_1.3.58.bb
index e839026..2f1f6c0 100644
--- a/meta/recipes-extended/chkconfig/chkconfig_1.3.58.bb
+++ b/meta/recipes-extended/chkconfig/chkconfig_1.3.58.bb
@@ -6,7 +6,7 @@ of the drudgery of manually editing the symbolic links."
 
 RECIPE_NO_UPDATE_REASON = "Version 1.5 requires selinux"
 
-HOMEPAGE = "http://fedorahosted.org/releases/c/h/chkconfig;
+HOMEPAGE = "https://github.com/fedora-sysv;
 
 LICENSE = "GPLv2"
 LIC_FILES_CHKSUM = "file://COPYING;md5=5574c6965ae5f583e55880e397fbb018"
@@ -16,12 +16,16 @@ PROVIDES += "virtual/update-alternatives"
 
 PR = "r7"
 
-SRC_URI = "http://fedorahosted.org/releases/c/h/chkconfig/${BPN}-${PV}.tar.bz2 
\
+S = "${WORKDIR}/${BPN}-${BPN}-${PV}"
+
+UPSTREAM_CHECK_URI = "https://github.com/fedora-sysv/${BPN}/releases;
+
+SRC_URI = 
"https://github.com/fedora-sysv/chkconfig/archive/chkconfig-${PV}.tar.gz \
file://replace_caddr_t.patch \
   "
 
-SRC_URI[md5sum] = "c2039ca67f2749fe0c06ef7c6f8ee246"
-SRC_URI[sha256sum] = 
"18b497d25b2cada955c72810e45fcad8280d105f17cf45e2970f18271211de68"
+SRC_URI[md5sum] = "3f51ac38a234be5278b3a2d9705eda5e"
+SRC_URI[sha256sum] = 
"bf1e81f0d7cc999b536c9fe7877abf584a4082fd03c9d2597b6f090966579b40"
 
 inherit gettext
 
-- 
2.7.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH v2 4/8] logrotate: replace fedorahosted.org SRC_URI with github.com source

2017-04-04 Thread yin . thong . choong
From: Choong YinThong 

fedorahosted.org was retired on March 1st, 2017. This is to
update the SRC_URI to point to github.com.

[YOCTO #11226]

Signed-off-by: Choong YinThong 
---
 meta/recipes-extended/logrotate/logrotate_3.9.1.bb | 12 
 1 file changed, 8 insertions(+), 4 deletions(-)

diff --git a/meta/recipes-extended/logrotate/logrotate_3.9.1.bb 
b/meta/recipes-extended/logrotate/logrotate_3.9.1.bb
index 9c2dfe0..586338c 100644
--- a/meta/recipes-extended/logrotate/logrotate_3.9.1.bb
+++ b/meta/recipes-extended/logrotate/logrotate_3.9.1.bb
@@ -1,6 +1,6 @@
 SUMMARY = "Rotates, compresses, removes and mails system log files"
 SECTION = "console/utils"
-HOMEPAGE = "https://fedorahosted.org/logrotate/;
+HOMEPAGE = "https://github.com/logrotate/logrotate/issues;
 LICENSE = "GPLv2"
 
 # TODO: logrotate 3.8.8 adds autotools/automake support, update recipe to use 
it.
@@ -10,14 +10,18 @@ DEPENDS="coreutils popt"
 
 LIC_FILES_CHKSUM = "file://COPYING;md5=18810669f13b87348459e611d31ab760"
 
-SRC_URI = 
"https://fedorahosted.org/releases/l/o/logrotate/logrotate-${PV}.tar.gz \
+S = "${WORKDIR}/${PN}-r3-9-1"
+
+UPSTREAM_CHECK_URI = "https://github.com/${PN}/${PN}/releases;
+
+SRC_URI = "https://github.com/${PN}/${PN}/archive/r3-9-1.tar.gz \
file://act-as-mv-when-rotate.patch \
file://update-the-manual.patch \
file://disable-check-different-filesystems.patch \
 "
 
-SRC_URI[md5sum] = "4492b145b6d542e4a2f41e77fa199ab0"
-SRC_URI[sha256sum] = 
"022769e3288c80981559a8421703c88e8438b447235e36dd3c8e97cd94c52545"
+SRC_URI[md5sum] = "8572b7c2cf9ade09a8a8e10098500fb3"
+SRC_URI[sha256sum] = 
"5bf8e478c428e7744fefa465118f8296e7e771c981fb6dffb7527856a0ea3617"
 
 PACKAGECONFIG ?= "${@bb.utils.filter('DISTRO_FEATURES', 'acl selinux', d)}"
 
-- 
2.7.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH v2 5/8] libnewt: replace fedorahosted.org SRC_URI with pagure.io source

2017-04-04 Thread yin . thong . choong
From: Choong YinThong 

fedorahosted.org was retired on March 1st, 2017. This is to
update the SRC_URI to point to pagure.io. pagure.io is a
replacement for fedorahosted.

[YOCTO #11226]

Signed-off-by: Choong YinThong 
---
 meta/recipes-extended/newt/libnewt_0.52.19.bb | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/meta/recipes-extended/newt/libnewt_0.52.19.bb 
b/meta/recipes-extended/newt/libnewt_0.52.19.bb
index a26ce1f..de76ce2 100644
--- a/meta/recipes-extended/newt/libnewt_0.52.19.bb
+++ b/meta/recipes-extended/newt/libnewt_0.52.19.bb
@@ -8,7 +8,7 @@ shared library needed by programs built with newt, as well as a 
\
 /usr/bin/dialog replacement called whiptail.  Newt is based on the \
 slang library."
 
-HOMEPAGE = "https://fedorahosted.org/newt/;
+HOMEPAGE = "https://releases.pagure.org/newt/;
 SECTION = "libs"
 
 LICENSE = "LGPLv2"
@@ -17,7 +17,7 @@ LIC_FILES_CHKSUM = 
"file://COPYING;md5=5f30f0716dfdd0d91eb439ebec522ec2"
 # slang needs to be >= 2.2
 DEPENDS = "slang popt"
 
-SRC_URI = "https://fedorahosted.org/releases/n/e/newt/newt-${PV}.tar.gz \
+SRC_URI = "https://releases.pagure.org/newt/newt-${PV}.tar.gz \
file://fix_SHAREDDIR.patch \
file://cross_ar.patch \
file://Makefile.in-Add-tinfo-library-to-the-linking-librari.patch \
-- 
2.7.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH v2 3/8] libuser: replace fedorahosted.org SRC_URI with pagure.io source

2017-04-04 Thread yin . thong . choong
From: Choong YinThong 

fedorahosted.org was retired on March 1st, 2017. This is to
update the SRC_URI to point to pagure.io. pagure.io is a
replacement for fedorahosted.

[YOCTO #11226]

Signed-off-by: Choong YinThong 
---
 meta/recipes-extended/libuser/libuser_0.62.bb | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/meta/recipes-extended/libuser/libuser_0.62.bb 
b/meta/recipes-extended/libuser/libuser_0.62.bb
index 6960d71..1765346 100644
--- a/meta/recipes-extended/libuser/libuser_0.62.bb
+++ b/meta/recipes-extended/libuser/libuser_0.62.bb
@@ -1,8 +1,8 @@
 SUMMARY = "user and group account administration library"
 DESCRIPTION = "The libuser library implements a standardized interface for 
manipulating and administering user \
 and group accounts"
-HOMEPAGE = "https://fedorahosted.org/libuser/;
-BUGTRACKER = "https://fedorahosted.org/libuser/newticket;
+HOMEPAGE = "https://pagure.io/libuser;
+BUGTRACKER = "https://pagure.io/libuser/issues;
 
 LICENSE = "LGPLv2"
 LIC_FILES_CHKSUM = "file://COPYING;md5=5f30f0716dfdd0d91eb439ebec522ec2 \
@@ -11,7 +11,7 @@ LIC_FILES_CHKSUM = 
"file://COPYING;md5=5f30f0716dfdd0d91eb439ebec522ec2 \
 
 SECTION = "base"
 
-SRC_URI = "https://fedorahosted.org/releases/l/i/libuser/libuser-${PV}.tar.xz \
+SRC_URI = "https://releases.pagure.org/libuser/libuser-${PV}.tar.xz \
file://0001-Check-for-issetugid.patch \
file://0002-remove-unused-execinfo.h.patch \

file://0001-modules-files.c-parse_field-fix-string-formating-in-.patch \
-- 
2.7.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH v2 2/8] xmlto: replace fedorahosted.org SRC_URI with pagure.io source

2017-04-04 Thread yin . thong . choong
From: Choong YinThong 

fedorahosted.org was retired on March 1st, 2017. This is to
update the SRC_URI to point to pagure.io. pagure.io is a
replacement for fedorahosted.

[YOCTO #11226]

Signed-off-by: Choong YinThong 
---
 meta/recipes-devtools/xmlto/xmlto_0.0.28.bb | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/meta/recipes-devtools/xmlto/xmlto_0.0.28.bb 
b/meta/recipes-devtools/xmlto/xmlto_0.0.28.bb
index ce5d1e0..6216d77 100644
--- a/meta/recipes-devtools/xmlto/xmlto_0.0.28.bb
+++ b/meta/recipes-devtools/xmlto/xmlto_0.0.28.bb
@@ -1,11 +1,11 @@
 SUMMARY = "A shell-script tool for converting XML files to various formats"
-HOMEPAGE = "https://fedorahosted.org/xmlto/;
+HOMEPAGE = "https://releases.pagure.org/xmlto/;
 SECTION = "docs/xmlto"
 LICENSE = "GPLv2"
 
 LIC_FILES_CHKSUM = "file://COPYING;md5=59530bdf33659b29e73d4adb9f9f6552"
 
-SRC_URI = "https://fedorahosted.org/releases/x/m/xmlto/xmlto-${PV}.tar.gz \
+SRC_URI = "https://releases.pagure.org/xmlto/xmlto-${PV}.tar.gz \
file://configure.in-drop-the-test-of-xmllint-and-xsltproc.patch \
file://catalog.xml \
 "
-- 
2.7.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH v2 0/8] Remove all use of fedorahosted SRC_URI [yocto #11226]

2017-04-04 Thread yin . thong . choong
From: Choong YinThong 

Fedorahosted.org was retired on March 1st, 2017.
Replace all fedorahosted.org SRC_URI with source pagure.io and github.com.

Choong YinThong (8):
  selftest/recipetool: replace fedorahosted.org SRC_URI with github.com
source
  xmlto: replace fedorahosted.org SRC_URI with pagure.io source
  libuser: replace fedorahosted.org SRC_URI with pagure.io source
  logrotate: replace fedorahosted.org SRC_URI with github.com source
  libnewt: replace fedorahosted.org SRC_URI with pagure.io source
  liberation-fonts: replace fedorahosted.org SRC_URI with pagure.io
source
  chkconfig: replace fedorahosted.org SRC_URI with github.com source
  cronie: replace fedorahosted.org SRC_URI with github.com source

 meta/lib/oeqa/selftest/recipetool.py |  8 
 meta/recipes-devtools/xmlto/xmlto_0.0.28.bb  |  4 ++--
 meta/recipes-extended/chkconfig/chkconfig_1.3.58.bb  | 12 
 meta/recipes-extended/cronie/cronie_1.5.1.bb |  6 --
 meta/recipes-extended/libuser/libuser_0.62.bb|  6 +++---
 meta/recipes-extended/logrotate/logrotate_3.9.1.bb   | 12 
 meta/recipes-extended/newt/libnewt_0.52.19.bb|  4 ++--
 meta/recipes-graphics/ttf-fonts/liberation-fonts_1.04.bb |  4 ++--
 8 files changed, 33 insertions(+), 23 deletions(-)

-- 
2.7.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH v2 1/8] selftest/recipetool: replace fedorahosted.org SRC_URI with github.com source

2017-04-04 Thread yin . thong . choong
From: Choong YinThong 

fedorahosted.org was retired on March 1st, 2017. This is to
update the SRC_URI to point to github.com.

[YOCTO #11226]

Signed-off-by: Choong YinThong 
---
 meta/lib/oeqa/selftest/recipetool.py | 8 
 1 file changed, 4 insertions(+), 4 deletions(-)

diff --git a/meta/lib/oeqa/selftest/recipetool.py 
b/meta/lib/oeqa/selftest/recipetool.py
index d62c8bb..d47b9dd 100644
--- a/meta/lib/oeqa/selftest/recipetool.py
+++ b/meta/lib/oeqa/selftest/recipetool.py
@@ -369,15 +369,15 @@ class RecipetoolTests(RecipetoolBase):
 tempsrc = os.path.join(self.tempdir, 'srctree')
 os.makedirs(tempsrc)
 recipefile = os.path.join(self.tempdir, 'logrotate_3.8.7.bb')
-srcuri = 
'https://fedorahosted.org/releases/l/o/logrotate/logrotate-3.8.7.tar.gz'
+srcuri = 'https://github.com/logrotate/logrotate/archive/r3-8-7.tar.gz'
 result = runCmd('recipetool create -o %s %s -x %s' % (recipefile, 
srcuri, tempsrc))
 self.assertTrue(os.path.isfile(recipefile))
 checkvars = {}
 checkvars['LICENSE'] = 'GPLv2'
 checkvars['LIC_FILES_CHKSUM'] = 
'file://COPYING;md5=18810669f13b87348459e611d31ab760'
-checkvars['SRC_URI'] = 
'https://fedorahosted.org/releases/l/o/logrotate/logrotate-${PV}.tar.gz'
-checkvars['SRC_URI[md5sum]'] = '99e08503ef24c3e2e3ff74cc5f3be213'
-checkvars['SRC_URI[sha256sum]'] = 
'f6ba691f40e30e640efa2752c1f9499a3f9738257660994de70a45fe00d12b64'
+checkvars['SRC_URI'] = 
'https://github.com/logrotate/logrotate/archive/r3-8-7.tar.gz'
+checkvars['SRC_URI[md5sum]'] = '6b1aa0e0d07eda3c9a2526520850397a'
+checkvars['SRC_URI[sha256sum]'] = 
'dece4bfeb9d8374a0ecafa34be139b5a697db5c926dcc69a9b8715431a22e733'
 self._test_recipe_contents(recipefile, checkvars, [])
 
 @testcase(1194)
-- 
2.7.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] ✗ patchtest: failure for linux-yocto: -stable, -rt updates and 4.8 removal (rev2)

2017-04-04 Thread Patchwork
== Series Details ==

Series: linux-yocto: -stable, -rt updates and 4.8 removal (rev2)
Revision: 2
URL   : https://patchwork.openembedded.org/series/6024/
State : failure

== Summary ==


Thank you for submitting this patch series to OpenEmbedded Core. This is
an automated response. Several tests have been executed on the proposed
series by patchtest resulting in the following failures:



* Issue Series does not apply on top of target branch 
[test_series_merge_on_head] 
  Suggested fixRebase your series on top of targeted branch
  Targeted branch  master (currently at 3b7111b30d)



If you believe any of these test results are incorrect, please reply to the
mailing list (openembedded-core@lists.openembedded.org) raising your concerns.
Otherwise we would appreciate you correcting the issues and submitting a new
version of the patchset if applicable. Please ensure you add/increment the
version number when sending the new version (i.e. [PATCH] -> [PATCH v2] ->
[PATCH v3] -> ...).

---
Test framework: http://git.yoctoproject.org/cgit/cgit.cgi/patchtest
Test suite: http://git.yoctoproject.org/cgit/cgit.cgi/patchtest-oe

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH] net-tools: Fix build with USE_NLS="no"

2017-04-04 Thread Jussi Kukkonen
The configuration change was already done for -native but
we really want it when USE_NLS is set.

Fixes [YOCTO #11285].

Signed-off-by: Jussi Kukkonen 
---
 meta/recipes-extended/net-tools/net-tools_1.60-26.bb | 14 --
 1 file changed, 4 insertions(+), 10 deletions(-)

diff --git a/meta/recipes-extended/net-tools/net-tools_1.60-26.bb 
b/meta/recipes-extended/net-tools/net-tools_1.60-26.bb
index 115b398..45d7bf4 100644
--- a/meta/recipes-extended/net-tools/net-tools_1.60-26.bb
+++ b/meta/recipes-extended/net-tools/net-tools_1.60-26.bb
@@ -70,21 +70,15 @@ python do_patch() {
 bb.build.exec_func('patch_do_patch', d)
 }
 
-# i18n only enabled for the target, doesn't build for native
-# and isn't needed there.
-disable_i18n() {
-   sed -i -e 's/^I18N=1/# I18N=1/' ${S}/config.make
-}
-disable_i18n_class-target () {
-   :
-}
-
 do_configure() {
# net-tools has its own config mechanism requiring "make config"
# we pre-generate desired options and copy to source directory instead
cp ${WORKDIR}/net-tools-config.h${S}/config.h
cp ${WORKDIR}/net-tools-config.make ${S}/config.make
-   disable_i18n
+
+   if [ "${USE_NLS}" = "no" ]; then
+   sed -i -e 's/^I18N=1/# I18N=1/' ${S}/config.make
+   fi
 }
 
 do_compile() {
-- 
2.1.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH V2] libjpeg-turbo: don't depend on NASM for non-x86 targets

2017-04-04 Thread Patrick Ohly
On Mon, 2017-04-03 at 18:25 +0100, Burton, Ross wrote:
> 
> On 3 April 2017 at 18:03, Andre McCurdy  wrote:
> > +EXTRA_OECONF_append_class-native = "--without-simd"
> 
> 
> Missing space?
> 
> 
> Argh.  V3 incoming.

I'm so glad that this can happen even to the best of us and not just
me ;-}

-- 
Best Regards, Patrick Ohly

The content of this message is my personal opinion only and although
I am an employee of Intel, the statements I make here in no way
represent Intel's position on the issue, nor am I authorized to speak
on behalf of Intel on this matter.



-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH] x86-base.inc, qemuarm.conf: prefer 4.10 version of linux-yocto

2017-04-04 Thread Martin Jansa
* 4.8 version was removed in:
  commit 466e6e45ca04a07ebe1b1f52de747f077b362d54
  Author: Bruce Ashfield 
  Date:   Tue Mar 28 08:58:07 2017 -0400

linux-yocto: drop 4.8 recipes

We have 4.1 (LTSI), 4.4 (LTS), 4.9 (LTS/LTSI) and 4.10 available in
master. 4.8 is no longer required, so we drop the recipe to keep
the version selection under control.
* causing each build to start with 188 lines of this stuff:
  NOTE: preferred version 4.8% of linux-yocto not available (for item 
virtual/kernel)
  NOTE: versions of linux-yocto available: 
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c 4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06 
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2 4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
  NOTE: preferred version 4.8% of linux-yocto not available (for item 
kernel-module-raid456)
  NOTE: versions of linux-yocto available: 
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c 4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06 
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2 4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a

Signed-off-by: Martin Jansa 
---
 meta/conf/machine/include/x86-base.inc | 2 +-
 meta/conf/machine/qemuarm.conf | 2 +-
 2 files changed, 2 insertions(+), 2 deletions(-)

diff --git a/meta/conf/machine/include/x86-base.inc 
b/meta/conf/machine/include/x86-base.inc
index 40d59577fd..7365953ca8 100644
--- a/meta/conf/machine/include/x86-base.inc
+++ b/meta/conf/machine/include/x86-base.inc
@@ -20,7 +20,7 @@ SERIAL_CONSOLE ?= "115200 ttyS0"
 # kernel-related variables
 #
 PREFERRED_PROVIDER_virtual/kernel ??= "linux-yocto"
-PREFERRED_VERSION_linux-yocto ??= "4.8%"
+PREFERRED_VERSION_linux-yocto ??= "4.10%"
 
 #
 # XSERVER subcomponents, used to build the XSERVER variable
diff --git a/meta/conf/machine/qemuarm.conf b/meta/conf/machine/qemuarm.conf
index f9d6dd7e36..6b875e415c 100644
--- a/meta/conf/machine/qemuarm.conf
+++ b/meta/conf/machine/qemuarm.conf
@@ -16,5 +16,5 @@ QB_MACHINE = "-machine versatilepb"
 QB_KERNEL_CMDLINE_APPEND = "console=ttyAMA0,115200 console=tty"
 # Add the 'virtio-rng-pci' device otherwise the guest may run out of entropy
 QB_OPT_APPEND = "-show-cursor -usb -usbdevice tablet -device virtio-rng-pci"
-PREFERRED_VERSION_linux-yocto ??= "4.8%"
+PREFERRED_VERSION_linux-yocto ??= "4.10%"
 QB_DTB = "${@base_version_less_or_equal('PREFERRED_VERSION_linux-yocto', 
'4.7', '', 'zImage-versatile-pb.dtb', d)}"
-- 
2.12.2

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 5/5] linux-yocto: drop 4.8 recipes

2017-04-04 Thread Bruce Ashfield

Adding Saul, since he mentioned that the defaults for x86 had
changed .. but now that I think about it, it was in the context
of the h/w reference boards.

Either way, I can take care of it .. I had thought that it was
already done, but the patch is simple to bump the default.

Bruce

On 04/04/2017 09:56 AM, Martin Jansa wrote:

What about updating preferred version, so that each build doesn't start
with this very nice output?

meta/conf/machine/include/x86-base.inc:PREFERRED_VERSION_linux-yocto ??=
"4.8%"
meta/conf/machine/qemuarm.conf:PREFERRED_VERSION_linux-yocto ??= "4.8%"

NOTE: Resolving any missing task queue dependencies
NOTE: preferred version 4.8% of linux-yocto not available (for item 
virtual/kernel)
NOTE: versions of linux-yocto available: 
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c 4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06 
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2 4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item 
kernel-module-raid456)
NOTE: versions of linux-yocto available: 
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c 4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06 
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2 4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item 
kernel-module-nfsd)
NOTE: versions of linux-yocto available: 
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c 4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06 
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2 4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item 
kernel-module-nf-log-ipv4)
NOTE: versions of linux-yocto available: 
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c 4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06 
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2 4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item 
kernel-module-autofs4)
NOTE: versions of linux-yocto available: 
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c 4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06 
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2 4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item 
kernel-module-nf-nat)
NOTE: versions of linux-yocto available: 
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c 4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06 
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2 4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item 
kernel-module-rtc-dev)
NOTE: versions of linux-yocto available: 
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c 4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06 
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2 4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item 
kernel-module-loop)
NOTE: versions of linux-yocto available: 
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c 4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06 
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2 4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item 
kernel-module-bnep)
NOTE: versions of linux-yocto available: 
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c 4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06 
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2 4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item 
kernel-module-ip-tables)
NOTE: versions of linux-yocto available: 
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c 4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06 
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2 4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item 
kernel-module-cdc-acm)
NOTE: versions of linux-yocto available: 
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c 4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06 
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2 4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item 
kernel-module-iptable-filter)
NOTE: versions of linux-yocto available: 
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c 4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06 
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2 4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item 
kernel-module-rtc-sysfs)
NOTE: versions of linux-yocto available: 
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c 4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06 
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2 4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item 
kernel-module-gadgetfs)
NOTE: versions of linux-yocto available: 
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c 4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06 
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2 4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item 
kernel-module-nf-addrtype)
NOTE: versions of linux-yocto available: 
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c 4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06 

Re: [OE-core] [PATCH 5/5] linux-yocto: drop 4.8 recipes

2017-04-04 Thread Martin Jansa
What about updating preferred version, so that each build doesn't start
with this very nice output?

meta/conf/machine/include/x86-base.inc:PREFERRED_VERSION_linux-yocto ??=
"4.8%"
meta/conf/machine/qemuarm.conf:PREFERRED_VERSION_linux-yocto ??= "4.8%"

NOTE: Resolving any missing task queue dependencies
NOTE: preferred version 4.8% of linux-yocto not available (for item
virtual/kernel)
NOTE: versions of linux-yocto available:
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c
4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2
4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item
kernel-module-raid456)
NOTE: versions of linux-yocto available:
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c
4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2
4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item
kernel-module-nfsd)
NOTE: versions of linux-yocto available:
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c
4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2
4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item
kernel-module-nf-log-ipv4)
NOTE: versions of linux-yocto available:
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c
4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2
4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item
kernel-module-autofs4)
NOTE: versions of linux-yocto available:
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c
4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2
4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item
kernel-module-nf-nat)
NOTE: versions of linux-yocto available:
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c
4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2
4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item
kernel-module-rtc-dev)
NOTE: versions of linux-yocto available:
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c
4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2
4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item
kernel-module-loop)
NOTE: versions of linux-yocto available:
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c
4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2
4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item
kernel-module-bnep)
NOTE: versions of linux-yocto available:
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c
4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2
4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item
kernel-module-ip-tables)
NOTE: versions of linux-yocto available:
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c
4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2
4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item
kernel-module-cdc-acm)
NOTE: versions of linux-yocto available:
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c
4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2
4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item
kernel-module-iptable-filter)
NOTE: versions of linux-yocto available:
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c
4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2
4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item
kernel-module-rtc-sysfs)
NOTE: versions of linux-yocto available:
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c
4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2
4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item
kernel-module-gadgetfs)
NOTE: versions of linux-yocto available:
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c
4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2
4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item
kernel-module-nf-addrtype)
NOTE: versions of linux-yocto available:
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c
4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2
4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: preferred version 4.8% of linux-yocto not available (for item
kernel-module-nf-conntrack)
NOTE: versions of linux-yocto available:
4.1.38+gitAUTOINC+7140ddb86e_4d2c95e78c
4.10.5+gitAUTOINC+01f18cba44_b97dcd4f06
4.4.56+gitAUTOINC+271b0c8d51_01aaede0a2
4.9.17+gitAUTOINC+8b97a445fa_3ff3760c2a
NOTE: 

Re: [OE-core] [PATCH] busybox.inc: drop comment explaining '-e MAKEFLAGS=' in EXTRA_OEMAKE

2017-04-04 Thread Peter Kjellerstedt
> -Original Message-
> From: openembedded-core-boun...@lists.openembedded.org
> [mailto:openembedded-core-boun...@lists.openembedded.org] On Behalf Of
> Andre McCurdy
> Sent: den 4 april 2017 03:59
> To: openembedded-core@lists.openembedded.org
> Subject: [OE-core] [PATCH] busybox.inc: drop comment explaining '-e
> MAKEFLAGS=' in EXTRA_OEMAKE
> 
> EXTRA_OEMAKE no longer contains '-e MAKEFLAGS=' so the comment
> explaining that it needs to be removed / over-ridden is obsolete.
> 
> Signed-off-by: Andre McCurdy 
> ---
>  meta/recipes-core/busybox/busybox.inc | 1 -
>  1 file changed, 1 deletion(-)
> 
> diff --git a/meta/recipes-core/busybox/busybox.inc b/meta/recipes-
> core/busybox/busybox.inc
> index 6246c95..375632d 100644
> --- a/meta/recipes-core/busybox/busybox.inc
> +++ b/meta/recipes-core/busybox/busybox.inc
> @@ -18,7 +18,6 @@ BUSYBOX_SPLIT_SUID ?= "1"
>  export EXTRA_CFLAGS = "${CFLAGS}"
>  export EXTRA_LDFLAGS = "${LDFLAGS}"
> 
> -# We don't want '-e MAKEFLAGS=' in EXTRA_OEMAKE
>  EXTRA_OEMAKE = "CC='${CC}' LD='${CCLD}' V=1 ARCH=${TARGET_ARCH} 
> CROSS_COMPILE=${TARGET_PREFIX} SKIP_STRIP=y HOSTCC='${BUILD_CC}' 
> HOSTCPP='${BUILD_CPP}'"

Given that the comment presumably was there to explain why 
"EXTRA_OEMAKE = ..." is used rather than the customary 
"EXTRA_OEMAKE += ...", maybe the code should be changed to 
actually use += instead now that EXTRA_OEMAKE no longer 
contains -e by default.

>  PACKAGES =+ "${PN}-httpd ${PN}-udhcpd ${PN}-udhcpc ${PN}-syslog ${PN}-mdev 
> ${PN}-hwclock"
> --
> 1.9.1

//Peter

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH 3/3] base-files: profile: Simplify setting variables conditionally

2017-04-04 Thread Peter Kjellerstedt
> -Original Message-
> From: Leonardo Sandoval
> [mailto:leonardo.sandoval.gonza...@linux.intel.com]
> Sent: den 3 april 2017 17:45
> To: Peter Kjellerstedt 
> Cc: openembedded-core@lists.openembedded.org
> Subject: Re: [OE-core] [PATCH 3/3] base-files: profile: Simplify
> setting variables conditionally
> 
> On Mon, 2017-04-03 at 14:48 +0200, Peter Kjellerstedt wrote:
> > It is preferred to use `[ "$FOO" ] || ...` instead of
> > `[ -z "$FOO" ] && ...` as the latter leaves $? set to 1.
> >
> > Signed-off-by: Peter Kjellerstedt 
> > ---
> >  meta/recipes-core/base-files/base-files/profile | 14 ++
> >  1 file changed, 6 insertions(+), 8 deletions(-)
> >
> > diff --git a/meta/recipes-core/base-files/base-files/profile 
> > b/meta/recipes-core/base-files/base-files/profile
> > index ceaf15f799..a062028226 100644
> > --- a/meta/recipes-core/base-files/base-files/profile
> > +++ b/meta/recipes-core/base-files/base-files/profile
> > @@ -3,15 +3,13 @@
> >
> >  PATH="/usr/local/bin:/usr/bin:/bin"
> >  EDITOR="vi"# needed for packages like cron, 
> > git-commit
> > -test -z "$TERM" && TERM="vt100"# Basic terminal capab. For screen etc.
> > +[ "$TERM" ] || TERM="vt100"# Basic terminal capab. For screen etc.
> >
> > -if [ "$HOME" = "ROOTHOME" ]; then
> > -   PATH=$PATH:/usr/local/sbin:/usr/sbin:/sbin
> > -fi
> > -if [ "$PS1" ]; then
> > -   # works for bash and ash (no other shells known to be in use here)
> > -   PS1='\u@\h:\w\$ '
> > -fi
> > +# Add /sbin & co to $PATH for the root user
> > +[ "$HOME" != "ROOTHOME" ] || PATH=$PATH:/usr/local/sbin:/usr/sbin:/sbin
> > +
> > +# Set the prompt for bash and ash (no other shells known to be in use here)
> > +[ -z "$PS1" ] || PS1='\u@\h:\w\$ '
> 
> Here you are using [ -z ] instead of [ ], is this intended? I do not
> think so based on your commit message.

Yes, it is intentional to maintain the original functionality. 
However, I may have to update the commit message a bit. It was 
written when I had only done the change for the $TERM variable.

> >
> >  if [ -d /etc/profile.d ]; then
> > for i in /etc/profile.d/*.sh; do
> > --
> > 2.12.0

//Peter

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH v2] libxml2: make dependencies on python conditional

2017-04-04 Thread Dmitry Rozhkov
The library libxml2 can provide its own bindings for python2 in addition
to the third party python-lxml and python3-lxml packages if this
functionality is enabled in PACKAGECONFIG.

But in case the functionality is disabled there's no need to depend
on python2.

Make the dependency on python2 enabled only if the python feature
is added to PACKAGECONFIG. Also add missing run-time dependency on make
to libxml2-ptest.

Signed-off-by: Dmitry Rozhkov 
---

Changes in v2:
- Set PACKAGECONFIG before it's used.
- PACKAGES is left unchanged because empty packages are not generated.

 meta/recipes-core/libxml/libxml2_2.9.4.bb | 20 +++-
 1 file changed, 11 insertions(+), 9 deletions(-)

diff --git a/meta/recipes-core/libxml/libxml2_2.9.4.bb 
b/meta/recipes-core/libxml/libxml2_2.9.4.bb
index 023fe99..0c3d683 100644
--- a/meta/recipes-core/libxml/libxml2_2.9.4.bb
+++ b/meta/recipes-core/libxml/libxml2_2.9.4.bb
@@ -32,22 +32,24 @@ SRC_URI[testtar.sha256sum] = 
"96151685cec997e1f9f3387e3626d61e6284d4d6e66e0e440c
 
 BINCONFIG = "${bindir}/xml2-config"
 
-inherit autotools pkgconfig binconfig-disabled pythonnative ptest
+PACKAGECONFIG ??= "python \
+${@bb.utils.filter('DISTRO_FEATURES', 'ipv6', d)} \
+"
+PACKAGECONFIG[python] = "--with-python=${PYTHON},--without-python,python"
+PACKAGECONFIG[ipv6] = "--enable-ipv6,--disable-ipv6,"
+
+inherit autotools pkgconfig binconfig-disabled ptest
+
+inherit ${@bb.utils.contains('PACKAGECONFIG', 'python', 'pythonnative', '', d)}
 
-RDEPENDS_${PN}-ptest += "python-core"
+RDEPENDS_${PN}-ptest += "make ${@bb.utils.contains('PACKAGECONFIG', 'python', 
'python-core', '', d)}"
 
-RDEPENDS_${PN}-python += "python-core"
+RDEPENDS_${PN}-python += "${@bb.utils.contains('PACKAGECONFIG', 'python', 
'python-core', '', d)}"
 
 RDEPENDS_${PN}-ptest_append_libc-glibc = " glibc-gconv-ebcdic-us 
glibc-gconv-ibm1141"
 
 export PYTHON_SITE_PACKAGES="${PYTHON_SITEPACKAGES_DIR}"
 
-PACKAGECONFIG ??= "python \
-${@bb.utils.filter('DISTRO_FEATURES', 'ipv6', d)} \
-"
-PACKAGECONFIG[python] = "--with-python=${PYTHON},--without-python,python"
-PACKAGECONFIG[ipv6] = "--enable-ipv6,--disable-ipv6,"
-
 # WARNING: zlib is require for RPM use
 EXTRA_OECONF = "--without-debug --without-legacy --with-catalog 
--without-docbook --with-c14n --without-lzma --with-fexceptions"
 EXTRA_OECONF_class-native = "--without-legacy --without-docbook --with-c14n 
--without-lzma --with-zlib"
-- 
2.7.4

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


Re: [OE-core] [PATCH] x86-base.inc, qemuarm.conf: prefer 4.10 version of linux-yocto

2017-04-04 Thread Martin Jansa
On Tue, Apr 04, 2017 at 10:48:54AM +0100, Burton, Ross wrote:
> On 4 April 2017 at 09:02, Martin Jansa  wrote:
> 
> > -PREFERRED_VERSION_linux-yocto ??= "4.8%"
> > +PREFERRED_VERSION_linux-yocto ??= "4.10%"
> >
> 
> The qemuppc and qemumips machines don't have a preferred version, so should
> we be setting it in all the machine configurations, or can we remove it
> from these recipes?

I don't really care, I don't use linux-yocto for anything useful, only
when testing the regressions in "bitbake world" builds and those 188
lines of NOTEs is all I care about.

-- 
Martin 'JaMa' Jansa jabber: martin.ja...@gmail.com


signature.asc
Description: Digital signature
-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] ✗ patchtest: failure for sanity: explain where TMPDIR is if we're telling the user to delete it (rev2)

2017-04-04 Thread Patchwork
== Series Details ==

Series: sanity: explain where TMPDIR is if we're telling the user to delete it 
(rev2)
Revision: 2
URL   : https://patchwork.openembedded.org/series/6146/
State : failure

== Summary ==


Thank you for submitting this patch series to OpenEmbedded Core. This is
an automated response. Several tests have been executed on the proposed
series by patchtest resulting in the following failures:



* Issue Patch line too long (current length 214) 
[test_max_line_length] 
  Suggested fixShorten the corresponding patch line (max length supported 
180)
  Patchmeta/classes/sanity.bbclass
  Line +status.addresult("The layout of TMPDIR changed 
for Recipe Specific  ...



If you believe any of these test results are incorrect, please reply to the
mailing list (openembedded-core@lists.openembedded.org) raising your concerns.
Otherwise we would appreciate you correcting the issues and submitting a new
version of the patchset if applicable. Please ensure you add/increment the
version number when sending the new version (i.e. [PATCH] -> [PATCH v2] ->
[PATCH v3] -> ...).

---
Test framework: http://git.yoctoproject.org/cgit/cgit.cgi/patchtest
Test suite: http://git.yoctoproject.org/cgit/cgit.cgi/patchtest-oe

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core


[OE-core] [PATCH 2/2] selftest/devtool: use kernel provider instead of recipe allowing other kernel providers

2017-04-04 Thread leonardo . sandoval . gonzalez
From: Leonardo Sandoval 

To generalize the unit test for other kernel providers, use virtual/kernel 
instead
of linux-yocto, allowing to run the selftest on non-poky distros, i.e. 
poky-tiny.

Signed-off-by: Leonardo Sandoval 
---
 meta/lib/oeqa/selftest/devtool.py | 23 ---
 1 file changed, 12 insertions(+), 11 deletions(-)

diff --git a/meta/lib/oeqa/selftest/devtool.py 
b/meta/lib/oeqa/selftest/devtool.py
index 7e65e52..762c7ba 100644
--- a/meta/lib/oeqa/selftest/devtool.py
+++ b/meta/lib/oeqa/selftest/devtool.py
@@ -1636,18 +1636,19 @@ class DevtoolTests(DevtoolBase):
 #verify the modification.
 features = 'MACHINE = "qemux86"\n'
 self.write_config(features)
+kernel_provider = get_bb_var('PREFERRED_PROVIDER_virtual/kernel')
 # Clean up the enviroment
-bitbake('linux-yocto -c cleansstate')
+bitbake('%s -c cleansstate' % kernel_provider)
 tempdir = tempfile.mkdtemp(prefix='devtoolqa')
 self.track_for_cleanup(tempdir)
 self.track_for_cleanup(self.workspacedir)
 self.add_command_to_tearDown('bitbake-layers remove-layer */workspace')
-self.add_command_to_tearDown('bitbake -c clean linux-yocto')
+self.add_command_to_tearDown('bitbake -c clean %s' % kernel_provider)
 #Step 1
 #Here is just generated the config file instead of all the kernel to 
optimize the
 #time of executing this test case.
-bitbake('linux-yocto -c configure')
-bbconfig = os.path.join(get_bb_var('B',"linux-yocto"),'.config')
+bitbake('%s -c configure' % kernel_provider)
+bbconfig = os.path.join(get_bb_var('B', kernel_provider),'.config')
 buildir= get_bb_var('TOPDIR')
 #Step 2
 runCmd('cp %s %s' % (bbconfig, buildir))
@@ -1656,7 +1657,7 @@ class DevtoolTests(DevtoolBase):
 
 tmpconfig = os.path.join(buildir, '.config')
 #Step 3
-bitbake('linux-yocto -c clean')
+bitbake('%s -c clean' % kernel_provider)
 #Step 4.1
 runCmd('devtool modify virtual/kernel -x %s' % tempdir)
 self.assertTrue(os.path.exists(os.path.join(tempdir, 'Makefile')),
@@ -1666,10 +1667,10 @@ class DevtoolTests(DevtoolBase):
 diff = runCmd('diff %s %s' % (tmpconfig, configfile))
 self.assertEqual(0,diff.status,'Kernel .config file is not the same 
using bitbake and devtool')
 #Step 4.3
-#NOTE: virtual/kernel is mapped to linux-yocto
-result = runCmd('devtool build linux-yocto')
+#NOTE: virtual/kernel is mapped to kernel_provider
+result = runCmd('devtool build %s' % kernel_provider)
 self.assertEqual(0,result.status,'Cannot build kernel using `devtool 
build`')
-kernelfile = os.path.join(get_bb_var('KBUILD_OUTPUT',"linux-yocto"), 
'vmlinux')
+kernelfile = os.path.join(get_bb_var('KBUILD_OUTPUT', 
kernel_provider), 'vmlinux')
 self.assertTrue(os.path.exists(kernelfile),'Kernel was not build 
correctly')
 
 #Modify the kernel source, this is specific for qemux86
@@ -1683,11 +1684,11 @@ class DevtoolTests(DevtoolBase):
 modconf = runCmd("sed -i 's/CONFIG_SG_POOL=y/%s/' %s" % (modconfopt, 
codeconfigfile))
 self.assertEqual(0,modconf.status,'Modification to %s failed' % 
codeconfigfile)
 #Build again kernel with devtool
-rebuild = runCmd('devtool build linux-yocto')
+rebuild = runCmd('devtool build %s' % kernel_provider)
 self.assertEqual(0,rebuild.status,'Fail to build kernel after 
modification of source and config')
 #Step 4.4
-bzimagename = 'bzImage-' + 
get_bb_var('KERNEL_VERSION_NAME',"linux-yocto")
-bzimagefile = os.path.join(get_bb_var('D',"linux-yocto"),'boot', 
bzimagename)
+bzimagename = 'bzImage-' + get_bb_var('KERNEL_VERSION_NAME', 
kernel_provider)
+bzimagefile = os.path.join(get_bb_var('D', kernel_provider),'boot', 
bzimagename)
 checkmodcode = runCmd("grep '%s' %s" % (modstring, bzimagefile))
 self.assertEqual(0,checkmodcode.status,'Modification on kernel source 
failed')
 #Step 4.5
-- 
2.9.3

-- 
___
Openembedded-core mailing list
Openembedded-core@lists.openembedded.org
http://lists.openembedded.org/mailman/listinfo/openembedded-core